@@ -1,6 +1,7 @@
 from pianosdk.user.api.user_api import UserApi
 from pianosdk.user.api.user_access_api import UserAccessApi
 from pianosdk.publisher.api.publisher_adblocker_api import PublisherAdblockerApi
+from pianosdk.publisher.api.publisher_afc_configuration_api import PublisherAfcConfigurationApi
 from pianosdk.publisher.api.publisher_app_api import PublisherAppApi
 from pianosdk.publisher.api.publisher_app_api_token_api import PublisherAppApiTokenApi
 from pianosdk.publisher.api.publisher_app_features_api import PublisherAppFeaturesApi
@@ -11,6 +12,8 @@ from pianosdk.publisher.api.publisher_conversion_custom_api import PublisherConv
 from pianosdk.publisher.api.publisher_conversion_data_api import PublisherConversionDataApi
 from pianosdk.publisher.api.publisher_conversion_external_api import PublisherConversionExternalApi
 from pianosdk.publisher.api.publisher_conversion_registration_api import PublisherConversionRegistrationApi
+from pianosdk.publisher.api.publisher_email_confirmation_api import PublisherEmailConfirmationApi
+from pianosdk.publisher.api.publisher_experience_metadata_api import PublisherExperienceMetadataApi
 from pianosdk.publisher.api.publisher_export_api import PublisherExportApi
 from pianosdk.publisher.api.publisher_export_create_api import PublisherExportCreateApi
 from pianosdk.publisher.api.publisher_export_create_aam_api import PublisherExportCreateAamApi
@@ -47,6 +50,8 @@ from pianosdk.publisher.api.publisher_payment_method_api import PublisherPayment
 from pianosdk.publisher.api.publisher_payment_method_billing_address_api import PublisherPaymentMethodBillingAddressApi
 from pianosdk.publisher.api.publisher_payment_method_gmo_api import PublisherPaymentMethodGmoApi
 from pianosdk.publisher.api.publisher_payment_provider_configuration_api import PublisherPaymentProviderConfigurationApi
+from pianosdk.publisher.api.publisher_platform_billing_configuration_api import PublisherPlatformBillingConfigurationApi
+from pianosdk.publisher.api.publisher_platform_billing_configuration_account_api import PublisherPlatformBillingConfigurationAccountApi
 from pianosdk.publisher.api.publisher_promotion_api import PublisherPromotionApi
 from pianosdk.publisher.api.publisher_promotion_code_api import PublisherPromotionCodeApi
 from pianosdk.publisher.api.publisher_promotion_fixed_discount_api import PublisherPromotionFixedDiscountApi
@@ -106,17 +111,22 @@ from pianosdk.anon.api.exposure_api import ExposureApi
 from pianosdk.anon.api.oauth_api import OauthApi
 from pianosdk.anon.api.subscription_api import SubscriptionApi
 from pianosdk.anon.api.swg_sync_api import SwgSyncApi
+from pianosdk.id.api.identity_api import IdentityApi
 from pianosdk.id.api.identity_oauth_api import IdentityOauthApi
 from pianosdk.id.api.identity_token_api import IdentityTokenApi
 from pianosdk.id.api.publisher_api import PublisherApi
 from pianosdk.id.api.publisher_audit_api import PublisherAuditApi
 from pianosdk.id.api.publisher_form_api import PublisherFormApi
 from pianosdk.id.api.publisher_identity_api import PublisherIdentityApi
+from pianosdk.id.api.publisher_identity_doi_api import PublisherIdentityDoiApi
+from pianosdk.id.api.publisher_identity_session_api import PublisherIdentitySessionApi
 from pianosdk.id.api.publisher_identity_set_api import PublisherIdentitySetApi
 from pianosdk.id.api.publisher_import_custom_fields_api import PublisherImportCustomFieldsApi
+from pianosdk.id.api.publisher_link_api import PublisherLinkApi
 from pianosdk.id.api.publisher_login_api import PublisherLoginApi
 from pianosdk.id.api.publisher_login_social_api import PublisherLoginSocialApi
 from pianosdk.id.api.publisher_reset_api import PublisherResetApi
+from pianosdk.id.api.publisher_social_api import PublisherSocialApi
 from pianosdk.id.api.publisher_token_api import PublisherTokenApi
 from pianosdk.id.api.publisher_userinfo_api import PublisherUserinfoApi
 from pianosdk.id.api.publisher_users_api import PublisherUsersApi
@@ -208,6 +218,10 @@ class Client:
     def publisher_adblocker_api(self) -> PublisherAdblockerApi:
         return PublisherAdblockerApi(self.config, self.http_callback)
 
+    @cached_property
+    def publisher_afc_configuration_api(self) -> PublisherAfcConfigurationApi:
+        return PublisherAfcConfigurationApi(self.config, self.http_callback)
+
     @cached_property
     def publisher_app_api(self) -> PublisherAppApi:
         return PublisherAppApi(self.config, self.http_callback)
@@ -248,6 +262,14 @@ class Client:
     def publisher_conversion_registration_api(self) -> PublisherConversionRegistrationApi:
         return PublisherConversionRegistrationApi(self.config, self.http_callback)
 
+    @cached_property
+    def publisher_email_confirmation_api(self) -> PublisherEmailConfirmationApi:
+        return PublisherEmailConfirmationApi(self.config, self.http_callback)
+
+    @cached_property
+    def publisher_experience_metadata_api(self) -> PublisherExperienceMetadataApi:
+        return PublisherExperienceMetadataApi(self.config, self.http_callback)
+
     @cached_property
     def publisher_export_api(self) -> PublisherExportApi:
         return PublisherExportApi(self.config, self.http_callback)
@@ -392,6 +414,14 @@ class Client:
     def publisher_payment_provider_configuration_api(self) -> PublisherPaymentProviderConfigurationApi:
         return PublisherPaymentProviderConfigurationApi(self.config, self.http_callback)
 
+    @cached_property
+    def publisher_platform_billing_configuration_api(self) -> PublisherPlatformBillingConfigurationApi:
+        return PublisherPlatformBillingConfigurationApi(self.config, self.http_callback)
+
+    @cached_property
+    def publisher_platform_billing_configuration_account_api(self) -> PublisherPlatformBillingConfigurationAccountApi:
+        return PublisherPlatformBillingConfigurationAccountApi(self.config, self.http_callback)
+
     @cached_property
     def publisher_promotion_api(self) -> PublisherPromotionApi:
         return PublisherPromotionApi(self.config, self.http_callback)
@@ -628,6 +658,10 @@ class Client:
     def swg_sync_api(self) -> SwgSyncApi:
         return SwgSyncApi(self.config, self.http_callback)
 
+    @cached_property
+    def identity_api(self) -> IdentityApi:
+        return IdentityApi(self.config, self.http_callback)
+
     @cached_property
     def identity_oauth_api(self) -> IdentityOauthApi:
         return IdentityOauthApi(self.config, self.http_callback)
@@ -652,6 +686,14 @@ class Client:
     def publisher_identity_api(self) -> PublisherIdentityApi:
         return PublisherIdentityApi(self.config, self.http_callback)
 
+    @cached_property
+    def publisher_identity_doi_api(self) -> PublisherIdentityDoiApi:
+        return PublisherIdentityDoiApi(self.config, self.http_callback)
+
+    @cached_property
+    def publisher_identity_session_api(self) -> PublisherIdentitySessionApi:
+        return PublisherIdentitySessionApi(self.config, self.http_callback)
+
     @cached_property
     def publisher_identity_set_api(self) -> PublisherIdentitySetApi:
         return PublisherIdentitySetApi(self.config, self.http_callback)
@@ -660,6 +702,10 @@ class Client:
     def publisher_import_custom_fields_api(self) -> PublisherImportCustomFieldsApi:
         return PublisherImportCustomFieldsApi(self.config, self.http_callback)
 
+    @cached_property
+    def publisher_link_api(self) -> PublisherLinkApi:
+        return PublisherLinkApi(self.config, self.http_callback)
+
     @cached_property
     def publisher_login_api(self) -> PublisherLoginApi:
         return PublisherLoginApi(self.config, self.http_callback)
@@ -672,6 +718,10 @@ class Client:
     def publisher_reset_api(self) -> PublisherResetApi:
         return PublisherResetApi(self.config, self.http_callback)
 
+    @cached_property
+    def publisher_social_api(self) -> PublisherSocialApi:
+        return PublisherSocialApi(self.config, self.http_callback)
+
     @cached_property
     def publisher_token_api(self) -> PublisherTokenApi:
         return PublisherTokenApi(self.config, self.http_callback)
