@@ -10,6 +10,7 @@ from pianosdk.publisher.api.publisher_conversion_custom_api import PublisherConv
 from pianosdk.publisher.api.publisher_conversion_data_api import PublisherConversionDataApi
 from pianosdk.publisher.api.publisher_conversion_external_api import PublisherConversionExternalApi
 from pianosdk.publisher.api.publisher_conversion_registration_api import PublisherConversionRegistrationApi
+from pianosdk.publisher.api.publisher_email_confirmation_api import PublisherEmailConfirmationApi
 from pianosdk.publisher.api.publisher_experience_metadata_api import PublisherExperienceMetadataApi
 from pianosdk.publisher.api.publisher_export_api import PublisherExportApi
 from pianosdk.publisher.api.publisher_export_create_api import PublisherExportCreateApi
@@ -47,6 +48,8 @@ from pianosdk.publisher.api.publisher_payment_method_api import PublisherPayment
 from pianosdk.publisher.api.publisher_payment_method_billing_address_api import PublisherPaymentMethodBillingAddressApi
 from pianosdk.publisher.api.publisher_payment_method_gmo_api import PublisherPaymentMethodGmoApi
 from pianosdk.publisher.api.publisher_payment_provider_configuration_api import PublisherPaymentProviderConfigurationApi
+from pianosdk.publisher.api.publisher_platform_billing_configuration_api import PublisherPlatformBillingConfigurationApi
+from pianosdk.publisher.api.publisher_platform_billing_configuration_account_api import PublisherPlatformBillingConfigurationAccountApi
 from pianosdk.publisher.api.publisher_promotion_api import PublisherPromotionApi
 from pianosdk.publisher.api.publisher_promotion_code_api import PublisherPromotionCodeApi
 from pianosdk.publisher.api.publisher_promotion_fixed_discount_api import PublisherPromotionFixedDiscountApi
