@@ -18,6 +18,9 @@ from pianosdk.publisher.models.app import App
 from pianosdk.publisher.models.app_features import AppFeatures
 from pianosdk.publisher.models.app_resource_count import AppResourceCount
 from pianosdk.publisher.models.apply_payment_method_dto import ApplyPaymentMethodDTO
+
+
+
 from pianosdk.publisher.models.audit_changed_field_dto import AuditChangedFieldDto
 from pianosdk.publisher.models.avalara_configuration import AvalaraConfiguration
 from pianosdk.publisher.models.avalara_origin_address import AvalaraOriginAddress
@@ -216,6 +219,7 @@ from pianosdk.publisher.models.period_link_candidate import PeriodLinkCandidate
 from pianosdk.publisher.models.period_reference_dto import PeriodReferenceDTO
 from pianosdk.publisher.models.period_settings import PeriodSettings
 from pianosdk.publisher.models.permission_dto import PermissionDTO
+from pianosdk.publisher.models.platform_billing_configuration_dto import PlatformBillingConfigurationDTO
 from pianosdk.publisher.models.pp_configuration import PpConfiguration
 from pianosdk.publisher.models.ppc_currency_validation_dto import PpcCurrencyValidationDto
 from pianosdk.publisher.models.ppc_web_model import PpcWebModel
@@ -324,6 +328,7 @@ from pianosdk.publisher.models.update_delivery_schedule_response import UpdateDe
 from pianosdk.publisher.models.update_linked_term_request import UpdateLinkedTermRequest
 from pianosdk.publisher.models.upgrade_checkout_flow import UpgradeCheckoutFlow
 from pianosdk.publisher.models.upgrade_offer_model import UpgradeOfferModel
+from pianosdk.publisher.models.upgrade_offer_name import UpgradeOfferName
 from pianosdk.publisher.models.upgrade_offer_option_model import UpgradeOfferOptionModel
 from pianosdk.publisher.models.upgrade_offer_variant import UpgradeOfferVariant
 from pianosdk.publisher.models.upgrade_option import UpgradeOption
