@@ -4,7 +4,8 @@ from typing import Optional
 
 
 class TermInfo(BaseModel):
-    id: Optional[str] = None
+    term_id: Optional[str] = None
+    period_id: Optional[str] = None
     title: Optional[str] = None
     billing: Optional[str] = None
 
